CKEDITOR.plugins.setLang('youtube', 'sk', {
	button : 'Vložiť YouTube video',
	title : 'Vložiť YouTube video',
	txtEmbed : 'Vložiť Youtube Embed Video kódu',
	txtUrl : 'Vložiť pomocou YouTube video URL',
	txtWidth : 'Šírka',
	txtHeight : 'Výška',
	chkRelated : 'Zobraziť odporúčané videá po prehratí',
	txtStartAt : 'Začať prehrávanie videa (ss alebo mm:ss alebo hh:mm:ss)',
	chkPrivacy : 'Povoliť pokročilý mód súkromia',
	chkOlderCode : 'Použiť starú metódu vkladania',
	chkAutoplay: 'Automatické prehrávanie',
	chkControls: 'Zobraziť ovládacie prvky prehrávača',
	noCode : 'Musíte vložiť Youtube Embed kód alebo URL',
	invalidEmbed : 'Vložený kód nie je valídny',
	invalidUrl : 'Vložená URL nie je platná',
	or : 'alebo',
	noWidth : 'Prosím, zadajte šírku videa',
	invalidWidth : 'Zadajte valídnu šírku videa',
	noHeight : 'Prosím, zadajte výšku videa',
	invalidHeight : 'Zadajte valídnu výšku videa',
	invalidTime : 'Zadajte valídny formát začiatku prehrávania videa',
	txtResponsive : 'Prispôsobit rozmery videa rozmerom obrazovky (ignoruje šírku a výšku, prispôsobí sa šírke obrazovky)'
});
