CKEDITOR.plugins.setLang('youtube', 'es', {
    button : 'Embed YouTube video',
    title : 'Embed YouTube video',
    txtEmbed : 'Pegar el código embed',
    txtUrl : 'Pegar la URL al video de Youtube',
    txtWidth : 'Anchura',
    txtHeight : 'Altura',
    chkRelated : 'Mostrar videos sugeridos al final de este video',
    txtStartAt : 'Comenzar en (ss or mm:ss or hh:mm:ss)',
    chkPrivacy : 'Habilitar el modo privacy-enhanced',
    chkOlderCode : 'Usar código embed viejo',
    chkAutoplay: 'Autoplay',
    chkControls: 'Mostrar controles del reproductor',
    noCode : 'Debes de introducir un código embed o URL',
    invalidEmbed : 'El código embed introducido parece no ser valido',
    invalidUrl : 'La URL introducida parece no ser valida',
    or : 'o',
    noWidth : 'Debes de dar la anchura',
    invalidWidth : 'Da una anchura valida',
    noHeight : 'Debes dar una altura valida',
    invalidHeight : 'Da una altura valida',
    invalidTime : 'Da un tiempo de valido',
    txtResponsive : 'Hacer responsivo (ignorar anchura y altura, ajustar a la anchura)'
});
