{% load i18n %}

<div class="modal fade" id="delete-message-{{ message.pk }}" tabindex="-1" role="dialog" aria-labelledby="{% translate 'Delete Message' %}" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>

                <div class="modal-title">
                    {% translate "Delete Message" %}
                </div>
            </div>

            <div class="modal-body">
                <p>{% translate "Are you sure you want to delete this message?" %}</p>
                <p>{% translate "In case this is the topics first message or the only remaining message in this topic, the topic will be removed as well." %}</p>

                <div class="alert alert-danger" role="alert">
                    <p>{% translate "This action cannot be undone!" %}</p>
                </div>
            </div>

            <div class="modal-footer">
                <button type="button" class="btn btn-default btn-sm" data-dismiss="modal">
                    <i class="far fa-hand-paper"></i>
                    {% translate "Cancel" %}
                </button>

                <a id="modal-button-confirm" class="btn btn-danger btn-sm" role="button" href="{% url 'aa_forum:forum_message_delete' message.pk %}">
                    <i class="far fa-trash-alt"></i>
                    {% translate "Delete" %}
                </a>
            </div>
        </div>
    </div>
</div>
